==> nextcloud-29.0.9.tgz: nextcloud/apps/files_downloadlimit/l10n/ar.js <==
OC.L10N.register(
    "files_downloadlimit",
    {
    "Files download limit" : "حد أقصى لتنزيل الملفات",
    "File link share download limit" : "حد أقصى لروابط المشاركة لتنزيل الملفات",
    "This app allows limiting the number of downloads for external link shares." : "يسمح هذا التطبيق بتفييذ عدد التنزيلات لمشاركات الروابط الخارجية.",
    "Limit downloads" : "تقييد التنزيلات",
    "Set download limit" : "تعيين حد أقصى للتنزيل",
    "Setting a new limit will reset the download count" : "تعيين حد جديد سيؤدي إلى إعادة ضبط عداد التنزيلات",
    "The minimum limit is 1" : "الحد الأدني هو 1",
    "Failed to set download limit" : "تعذّر تعيين حد للتنزيل",
    "Failed to remove download limit" : "تعذّرت إزالة حد التنزيل",
    "_1 remaining download allowed_::_{count} remaining downloads allowed_" : ["{count} تنزيلات متبقية مسموح بها","1 تنزيل متبقى مسموح به","{count} تنزيلات متبقية مسموح بها","{count} تنزيلات متبقية مسموح بها","{count} تنزيلات متبقية مسموح بها","{count} تنزيلات متبقية مسموح بها"],
    "Download limit" : "حد التنزيل",
    "Configure the default download limit for external shares." : "تهيئة حد التنزيل الافتراضي للمشاركات الخارجية",
    "Set default download limit" : "تعيين حد التنزيل الافتراضي",
    "Failed to set default download limit" : "تعذّر تعيين حد التنزيل الافتراضي",
    "You have reached the maximum amount of downloads allowed" : "أنت وصلت إلى الحد الأقصى من التنزيلات المسموح بها",
    "This share has a limited number of downloads. Are you sure you want to trigger a new download?" : "هذه المُشاركة لها عدد محدد من التنزيلات. هل أنت متأكد أنك تريد بدء تنزيل جديد؟",
    "Allow to limit the number of downloads for link shares" : "إسمح بتقييد عدد التنزيلات لروابط المشاركة",
    "This share was limited to {limit} downloads. There is still {countLeft} left allowed." : "هذه المشاركة مُقيّدة بعدد {limit} تنزيل؛ مازال مٌتاحاً منها {countLeft} فقط. "
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");

==> nextcloud-29.0.12.tgz: nextcloud/apps/files_downloadlimit/l10n/ar.js <==
OC.L10N.register(
    "files_downloadlimit",
    {
    "Files download limit" : "حد أقصى لتنزيل الملفات",
    "File link share download limit" : "حد أقصى لروابط المشاركة لتنزيل الملفات",
    "This app allows limiting the number of downloads for external link shares." : "يسمح هذا التطبيق بتفييذ عدد التنزيلات لمشاركات الروابط الخارجية.",
    "Limit downloads" : "تقييد التنزيلات",
    "Set download limit" : "تعيين حد أقصى للتنزيل",
    "Setting a new limit will reset the download count" : "تعيين حد جديد سيؤدي إلى إعادة ضبط عداد التنزيلات",
    "The minimum limit is 1" : "الحد الأدنى هو 1",
    "Failed to set download limit" : "تعذّر تعيين حد للتنزيل",
    "Failed to remove download limit" : "تعذّرت إزالة حد التنزيل",
    "_1 remaining download allowed_::_{count} remaining downloads allowed_" : ["{count} تنزيلات متبقية مسموح بها","1 تنزيل متبقى مسموح به","{count} تنزيلات متبقية مسموح بها","{count} تنزيلات متبقية مسموح بها","{count} تنزيلات متبقية مسموح بها","{count} تنزيلات متبقية مسموح بها"],
    "Download limit" : "حد التنزيل",
    "Configure the default download limit for external shares." : "تهيئة حد التنزيل الافتراضي للمشاركات الخارجية",
    "Set default download limit" : "تعيين حد التنزيل الافتراضي",
    "Failed to set default download limit" : "تعذّر تعيين حد التنزيل الافتراضي",
    "You have reached the maximum amount of downloads allowed" : "أنت وصلت إلى الحد الأقصى من التنزيلات المسموح بها",
    "This share has a limited number of downloads. Are you sure you want to trigger a new download?" : "هذه المُشاركة لها عدد محدد من التنزيلات. هل أنت متأكد أنك تريد بدء تنزيل جديد؟"
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
